@@ -239,9 +239,9 @@ __all__ = ["cache_all", "compile", "DEFAULT_VERSION", "escape", "findall",
   "FULLCASE", "I", "IGNORECASE", "L", "LOCALE", "M", "MULTILINE", "P", "POSIX",
   "R", "REVERSE", "T", "TEMPLATE", "U", "UNICODE", "V0", "VERSION0", "V1",
   "VERSION1", "X", "VERBOSE", "W", "WORD", "error", "Regex", "__version__",
-  "__doc__"]
+  "__doc__", "RegexFlag"]
 
-__version__ = "2.5.96"
+__version__ = "2.5.119"
 
 # --------------------------------------------------------------------
 # Public interface.
@@ -346,9 +346,11 @@ def finditer(pattern, string, flags=0, pos=None, endpos=None, overlapped=False,
     return pat.finditer(string, pos, endpos, overlapped, concurrent, partial,
       timeout)
 
-def compile(pattern, flags=0, ignore_unused=False, **kwargs):
+def compile(pattern, flags=0, ignore_unused=False, cache_pattern=None, **kwargs):
     "Compile a regular expression pattern, returning a pattern object."
-    return _compile(pattern, flags, ignore_unused, kwargs, _cache_all)
+    if cache_pattern is None:
+        cache_pattern = _cache_all
+    return _compile(pattern, flags, ignore_unused, kwargs, cache_pattern)
 
 def purge():
     "Clear the regular expression cache"
@@ -470,6 +472,16 @@ def _compile(pattern, flags, ignore_unused, kwargs, cache_it):
         # This pattern is definitely not locale-sensitive.
         pattern_locale = None
 
+    def complain_unused_args():
+        if ignore_unused:
+            return
+
+        # Complain about any unused keyword arguments, possibly resulting from a typo.
+        unused_kwargs = set(kwargs) - {k for k, v in args_needed}
+        if unused_kwargs:
+            any_one = next(iter(unused_kwargs))
+            raise ValueError('unused keyword argument {!a}'.format(any_one))
+
     if cache_it:
         try:
             # Do we know what keyword arguments are needed?
@@ -485,6 +497,8 @@ def _compile(pattern, flags, ignore_unused, kwargs, cache_it):
                     except KeyError:
                         raise error("missing named list: {!r}".format(k))
 
+            complain_unused_args()
+
             args_supplied = frozenset(args_supplied)
 
             # Have we already seen this regular expression and named list?
@@ -595,11 +609,7 @@ def _compile(pattern, flags, ignore_unused, kwargs, cache_it):
         named_list_indexes[index] = items
         args_needed.add((name, values))
 
-    # Any unused keyword arguments, possibly resulting from a typo?
-    unused_kwargs = set(kwargs) - set(named_lists)
-    if unused_kwargs and not ignore_unused:
-        any_one = next(iter(unused_kwargs))
-        raise ValueError('unused keyword argument {!a}'.format(any_one))
+    complain_unused_args()
 
     # Check the features of the groups.
     _check_group_features(info, parsed)
